-- ElementalFireTimer 1.6, by Wikwocket (wikwocket@gmail.com)
-- 
-- Tells you when your Elemental Fire transmute has cooled down. (Also tracks Evergreen Herb Casings)
-- Uses embedded Chronos library for scheduling: http://www.wowinterface.com/downloads/fileinfo.php?id=4328
-- No options or slash commands necessary - just start transmuting!

-- Local variables for saving state
local numNotes1 = 0;
local numNotes2 = 0;

-- Event handler: called for CHAT_MSG_LOOT events.
--  If message was from transmute, take appropriate action
function ElementalFireTimerOnEvent()
	-- Elemental Fire transmute: schedule cooldown notices
	if (strfind(arg1, "You create") and strfind(arg1, "Elemental Fire")) then
		-- delete any pending notifications
		Chronos.unscheduleByName("ElementalFireTimer");
		-- schedule new 10-minute notification and let user know
		if (DEFAULT_CHAT_FRAME) then DEFAULT_CHAT_FRAME:AddMessage("Elemental Fire Transmute detected. You will be notified of the cooldown in 10 minutes."); end
		Chronos.scheduleByName("ElementalFireTimer", 900, ElementalFireTimerNotify, "Elemental Fire Transmute has cooled down", 1);
		-- also set up 4 re-notifications
		numNotes1 = 4;
	-- other transmute: cancel any pending notices
	elseif (strfind(arg1, "You create") and (strfind(arg1, "Essence") or strfind(arg1, "Arcanite Bar") or strfind(arg1, "Gold Bar") or strfind(arg1, "Truesilver Bar"))) then
		-- delete any pending notifications
		Chronos.unscheduleByName("ElementalFireTimer");
		numNotes1 = 0;
	-- Evergreen Herb Casings: track seperately
	elseif (strfind(arg1, "You receive") and strfind(arg1, "Evergreen Herb Casing")) then
		-- delete any pending notifications
		Chronos.unscheduleByName("ElementalFireTimerSeed");
		-- schedule new 10-minute notification and let user know
		if (DEFAULT_CHAT_FRAME) then DEFAULT_CHAT_FRAME:AddMessage("Evergreen Pouch use detected. You will be notified of the cooldown in 10 minutes."); end
		Chronos.scheduleByName("ElementalFireTimerSeed", 600, ElementalFireTimerNotify, "Evergreen Pouch has cooled down", 2);
		-- also set up 4 re-notifications
		numNotes2 = 4;
	end
end

-- Notify: tell user that transmute has cooled down. whichTransmute = 1 for EFT, 2 for seeds.
function ElementalFireTimerNotify(notifyText, whichTransmute)
	-- chat log message
	if (DEFAULT_CHAT_FRAME) then DEFAULT_CHAT_FRAME:AddMessage(notifyText); end
	-- big display message
	if UIErrorsFrame then
		UIErrorsFrame:AddMessage(notifyText, 1, 1, 0, 1.0, UIERRORS_HOLD_TIME)
	end
	-- play sound
	PlaySoundFile("Sound\\interface\\PickUp\\PutDownRing.wav");
	-- schedule additional notification
	if (whichTransmute == 1) then
		if (numNotes1 > 0) then
			Chronos.scheduleByName("ElementalFireTimer", 300, ElementalFireTimerNotify, "Elemental Fire Transmute is still cooled down", 1);
			numNotes1 = numNotes1 - 1;
		end
	elseif (whichTransmute == 2) then
		if (numNotes2 > 0) then
			Chronos.scheduleByName("ElementalFireTimerSeed", 300, ElementalFireTimerNotify, "Evergreen Pouch is still cooled down", 2);
			numNotes2 = numNotes2 - 1;
		end
	end
end
